==> ejc-zjkjscene-impl-3.0.0-20250213.091025-8-sources.jar: com/ejianc/busness/zjkjscene/bean/ScheduleReportEntity.java <==
package com.ejianc.busness.zjkjscene.bean;

import java.util.Date;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 工期履约填报
 * 
 * @author generator
 * 
 */
 @TableName("ejc_zjkjscene_schedule_report")
public class ScheduleReportEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="work_archive")
    private String workArchive; // 施工阶段
    @TableField(value="work_archive_name")
    private String workArchiveName; // 施工阶段名称
    @TableField(value="performance_state_id")
    private Long performanceStateId; // 履约状态
    @TableField(value="performance_state_name")
    private String performanceStateName; // 履约状态名称
    @TableField(value="performance_state_normal")
    private Boolean performanceStateNormal; // 履约状态是否正常
    @TableField(value="specific_reasons")
    private String specificReasons; // 具体原因

    @TableField(value="affect_total")
    private String affectTotal; // 是否影响总工期：正常：normal，是：Y，否：N
    @TableField(value="reportor_id")
    private Long reportorId; // 填报人id
    @TableField(value="reportor_name")
    private String reportorName; // 填报人名称
    @TableField(value="project_id")
    private Long projectId; // 填报项目名称id
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="report_date")
    private Date reportDate; // 填报日期
    @TableField(value="restock_report")
    private Boolean restockReport; // 是否补充填报
    @TableField(value="code")
    private String code; // 单据编码
    @TableField(value="bill_state")
    private Integer billState; // 单据状态

    public String getWorkArchive() {
        return workArchive;
    }

    public void setWorkArchive(String workArchive) {
        this.workArchive = workArchive;
    }

    public String getWorkArchiveName() {
        return workArchiveName;
    }

    public void setWorkArchiveName(String workArchiveName) {
        this.workArchiveName = workArchiveName;
    }

    public Long getPerformanceStateId() {
        return performanceStateId;
    }

    public void setPerformanceStateId(Long performanceStateId) {
        this.performanceStateId = performanceStateId;
    }
    public String getPerformanceStateName() {
        return performanceStateName;
    }

    public void setPerformanceStateName(String performanceStateName) {
        this.performanceStateName = performanceStateName;
    }
    public Boolean getPerformanceStateNormal() {
        return performanceStateNormal;
    }

    public void setPerformanceStateNormal(Boolean performanceStateNormal) {
        this.performanceStateNormal = performanceStateNormal;
    }
    public String getSpecificReasons() {
        return specificReasons;
    }

    public void setSpecificReasons(String specificReasons) {
        this.specificReasons = specificReasons;
    }
    public String getAffectTotal() {
        return affectTotal;
    }

    public void setAffectTotal(String affectTotal) {
        this.affectTotal = affectTotal;
    }
    public Long getReportorId() {
        return reportorId;
    }

    public void setReportorId(Long reportorId) {
        this.reportorId = reportorId;
    }
    public String getReportorName() {
        return reportorName;
    }

    public void setReportorName(String reportorName) {
        this.reportorName = reportorName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Date getReportDate() {
        return reportDate;
    }

    public void setReportDate(Date reportDate) {
        this.reportDate = reportDate;
    }
    public Boolean getRestockReport() {
        return restockReport;
    }

    public void setRestockReport(Boolean restockReport) {
        this.restockReport = restockReport;
    }
    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    
}

==> ejc-zjkjscene-impl-3.0.0-20250224.034452-27-sources.jar: com/ejianc/busness/zjkjscene/bean/ScheduleReportEntity.java <==
package com.ejianc.busness.zjkjscene.bean;

import java.util.Date;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 工期履约填报
 * 
 * @author generator
 * 
 */
 @TableName("ejc_zjkjscene_schedule_report")
public class ScheduleReportEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="work_archive")
    private String workArchive; // 施工阶段
    @TableField(value="work_archive_name")
    private String workArchiveName; // 施工阶段名称
    @TableField(value="performance_state_id")
    private Long performanceStateId; // 履约状态
    @TableField(value="performance_state_name")
    private String performanceStateName; // 履约状态名称
    @TableField(value="performance_state_normal")
    private Boolean performanceStateNormal; // 履约状态是否正常
    @TableField(value="specific_reasons")
    private String specificReasons; // 具体原因

    @TableField(value="affect_total")
    private String affectTotal; // 是否影响总工期：正常：normal，是：Y，否：N
    @TableField(value="reportor_id")
    private Long reportorId; // 填报人id
    @TableField(value="reportor_name")
    private String reportorName; // 填报人名称
    @TableField(value="project_id")
    private Long projectId; // 填报项目名称id
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="report_date")
    private Date reportDate; // 填报日期
    @TableField(value="restock_report")
    private Integer restockReport; // 是否补充填报：0：当天填报，1：申请补报，2：三天内补报
    @TableField(value="code")
    private String code; // 单据编码
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="project_type_id")
    private Long projectTypeId; // 项目类型id，用于施工阶段查询

    public String getWorkArchive() {
        return workArchive;
    }

    public void setWorkArchive(String workArchive) {
        this.workArchive = workArchive;
    }

    public String getWorkArchiveName() {
        return workArchiveName;
    }

    public void setWorkArchiveName(String workArchiveName) {
        this.workArchiveName = workArchiveName;
    }

    public Long getPerformanceStateId() {
        return performanceStateId;
    }

    public void setPerformanceStateId(Long performanceStateId) {
        this.performanceStateId = performanceStateId;
    }
    public String getPerformanceStateName() {
        return performanceStateName;
    }

    public void setPerformanceStateName(String performanceStateName) {
        this.performanceStateName = performanceStateName;
    }
    public Boolean getPerformanceStateNormal() {
        return performanceStateNormal;
    }

    public void setPerformanceStateNormal(Boolean performanceStateNormal) {
        this.performanceStateNormal = performanceStateNormal;
    }
    public String getSpecificReasons() {
        return specificReasons;
    }

    public void setSpecificReasons(String specificReasons) {
        this.specificReasons = specificReasons;
    }
    public String getAffectTotal() {
        return affectTotal;
    }

    public void setAffectTotal(String affectTotal) {
        this.affectTotal = affectTotal;
    }
    public Long getReportorId() {
        return reportorId;
    }

    public void setReportorId(Long reportorId) {
        this.reportorId = reportorId;
    }
    public String getReportorName() {
        return reportorName;
    }

    public void setReportorName(String reportorName) {
        this.reportorName = reportorName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Date getReportDate() {
        return reportDate;
    }

    public void setReportDate(Date reportDate) {
        this.reportDate = reportDate;
    }
    public Integer getRestockReport() {
        return restockReport;
    }

    public void setRestockReport(Integer restockReport) {
        this.restockReport = restockReport;
    }
    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public Long getProjectTypeId() {
        return projectTypeId;
    }

    public void setProjectTypeId(Long projectTypeId) {
        this.projectTypeId = projectTypeId;
    }
}
